@@ -138,6 +138,32 @@ my %template = (
 		    "┘"  ],
 	bottom =>    "─",
     },
+    shadow => {
+	top    =>   "",
+	left   => [ " "  ,
+		    " "  ,
+		    "▝" ],
+	center => [ " ▖ " ,
+		    " ▌ " ,
+		    "▀▘▝" ],
+	right  => [ " ▖" ,
+		    " ▌" ,
+		    "▀▘" ],
+	bottom =>   "▀",
+    },
+    shadow_box => {
+	top    =>   "─",
+	left   => [ "┌─"  ,
+		    "│ "  ,
+		    "└▄" ],
+	center => [ "─┐ ┌─"  ,
+		    " ▐ │ "  ,
+		    "▄▟ └▄" ],
+	right  => [ "─┐" ,
+		    " ▐" ,
+		    "▄▟" ],
+	bottom =>   "▄",
+    },
     comb => {
 	top    =>    "─",
 	left   => [ "┌─"  ,
